/*
SerialCommClass.h

Serial Comm functions
*/

#ifndef _SERIALCOMMCLASS_H
#define _SERIALCOMMCLASS_H

#include "XpertAPI.h"
#include "Xpert/Win32Fix.h"

#undef DECL
#if defined(NOT_XPERT)
#define DECL
#else
#if defined(_AFXDLL) || defined(XPERT_EXE)
#ifdef UTILS_DLL
#define DECL _declspec(dllexport)
#else
#define DECL _declspec(dllimport)
#endif
#else
#define DECL 
#endif
#endif

class DECL CSerialComm
{
public:
   CSerialComm();
   ~CSerialComm();
   CSerialComm(const TCHAR* CommPort);
   CSerialComm& operator=(const CSerialComm& SC);

   // open/close
   bool CloseComm();
   bool OpenComm();
   bool IsOpen() { return (m_hPort != INVALID_HANDLE_VALUE); };

   // configuration
   void SetConfiguration(DWORD BaudRate, BYTE ByteSize, BYTE Parity, BYTE StopBits, BOOL FlowCtrl);
   void SetCommPort(const TCHAR* CommPort) {_tcscpy(m_CommPort, CommPort);};
   void SetBaudRate(const DWORD BaudRate) {m_BaudRate = BaudRate;};
   void SetTimeouts(COMMTIMEOUTS& CommTimeouts) {m_CommTimeouts = CommTimeouts;};
   DWORD SetPower(DWORD State);
   DWORD GetPower();
   BOOL ResetWake(); // Put the uart back to sleep after it's auto-woken up (restore's the power state)
   // data
#ifdef UNICODE
   bool GetChar(char  * ch) {return GetChar((UCHAR*) ch);};
#endif
   bool GetChar(UCHAR * uch);
   bool GetChar(TCHAR * wch);

   // NOTE: Null terminates string, hence Str alloc better be at least 1 > than StrLen!!!
   int GetStr(UCHAR * Str, int StrLen); 
#ifdef UNICODE
   // NOTE: Null terminates string, hence Str alloc better be at least 1 > than StrLen!!!
   int GetStr(char *  Str, int StrLen) {return GetStr((UCHAR*)Str, StrLen);};
#endif
   // NOTE: Null terminates string, hence Str alloc better be at least 1 > than StrLen!!!
   int GetStr(TCHAR * Str, int StrLen);
   
   int Get(void* Buffer, int BufferLen);
   int Get(void* Buffer, int BufferLen, DWORD dwTimeout);

   bool Put(const void* Buffer, int BufferLen);
   bool PutAndWait(const void* Buffer, int BufferLen);
#ifdef UNICODE
   bool PutChar(const char  ch) {return PutChar((const UCHAR)ch);};
#endif
   bool PutChar(const UCHAR uch);
   bool PutChar(const TCHAR wch);


#ifdef UNICODE
   bool PutStr(const char * Str) {return PutStr((UCHAR*)Str);};
   bool PutStr(const char * Str, int StrLen) {return PutStr((UCHAR*)Str, StrLen);};
#endif
   bool PutStr(const UCHAR * Str) {return (PutStr(Str, strlen((char*)Str)));};
   bool PutStr(const UCHAR * Str, int StrLen);
   bool PutStr(TCHAR * Str) { return PutStr(Str, _tcsclen(Str));};
   bool PutStr(TCHAR * Str, int StrLen);
   bool PutStr(CString Str);

   int  NumberBytesInputBuffer(); // returns number of bytes in input buffer
   bool KeyPressed();             // return true if a key is in rx buffer
   void FlushInput();             // empties rx buffer

   HANDLE GetHandle() {return m_hPort;};

   void WaitOnRx();                // waits (blocks) until a char comes in the serial port - flushes input first
   void WaitForTxEmpty();          // waits (blocks) until transmit buffer empty.
   void WaitForTxEmpty(TCHAR LastCh); // More accurate version of WaitForTxEmpty()

   // When UartMode is set to RS485, the RS485 header on the Xlite is switched into 
   // the circuit, and the behavior of the driver changes, such that RTS drops 
   // automatically after tx buffer is completely emptied on a write. All the app 
   // code must do in this case is set RTS high before write. This behavior supports 
   // quick turn-around in RS485 half-duplex communications. 
   void SetUartMode(int iUartMode);
   int GetUartMode() {return m_iUartMode;};

protected:
   HANDLE  m_hPort;
   TCHAR   m_CommPort[8];
   DWORD   m_BaudRate;
   BOOL    m_HardwareFlow; // None/Hardware
   BYTE    m_ByteSize;     // number of bits per byte (4-8)
   BYTE    m_Parity;       // 0-4 = no,odd,even,mark,space
   BYTE    m_StopBits;     // 0,1,2 = 1, 1.5, 2

   int m_iUartMode;
   
   COMMTIMEOUTS m_CommTimeouts;
   DWORD PowerState;

public:
   DWORD TotalPut;
   DWORD TotalGet;
};


#endif
